==> sanjagh_flutter-0.0.3.tar.gz: android/src/main/java/com/sanjagh/sanjagh_flutter/SanjaghFlutterPlugin.java <==
package com.sanjagh.sanjagh_flutter;

import android.app.Activity;
import android.graphics.Color;
import android.view.Gravity;

import com.sanjagh.sdk.Sanjagh;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterSdkPlugin
 */
public class SanjaghFlutterPlugin implements MethodCallHandler {

  private final Registrar registrar;
  private final MethodChannel channel;



  private SanjaghFlutterPlugin(Registrar registrar, MethodChannel channel) {
    this.registrar = registrar;
    this.channel = channel;
  }

  /**
   * Plugin registration.
   */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_sdk");
    registrar
            .platformViewRegistry()
            .registerViewFactory(
                    "com.sanjagh.sdk/banner", new BannerViewFactory(registrar.messenger()));
    channel.setMethodCallHandler(new SanjaghFlutterPlugin(registrar, channel));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    int id = 0;
    if (call.hasArgument("id")){
      id = call.argument("id");
    }
    switch (call.method) {
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "initialize":
        initSDK((String) call.argument("appId"));
        break;
      case "setMarket":
        setMarket((int) call.argument("market"));
        break;
      case "setPrimaryColor":
        setPrimaryColor((String) call.argument("color"));
        break;
      case "setUserIdentifier":
        setUserIdentifier((String) call.argument("userIdentifier"));
        break;
      case "showBanner":
        callLoadBannerAd(id, registrar.activity(), channel, call, result);
        break;
      case "showNativeExpress":
        callLoadNativeExpressAd(id, registrar.activity(), channel, call ,result);
        break;
      case "loadInterstitialAd":
        callLoadInterstitialAd(MobileAd.createInterstitial(id, registrar.activity(), channel), call, result);
        break;
      case "showAd":
        callShowAd(id, call, result);
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  private void initSDK(String appId) {
    Sanjagh.initialize(registrar.activity().getApplication(), appId);
  }

  private void setMarket(int market) {
    @Sanjagh.Markets int m;
    switch (market){
      case 1:
        m = Sanjagh.MARKET_GOOGLE_PLAY;
        break;
      case 2:
        m = Sanjagh.MARKET_CAFE_BAZAAR;
        break;
      case 3:
        m = Sanjagh.MARKET_MYKET;
        break;
      case 4:
        m = Sanjagh.MARKET_IRAN_APPS;
        break;
      case 5:
        m = Sanjagh.MARKET_AVVAL_MARKET;
        break;
      case 6:
        m = Sanjagh.MARKET_CANDO;
        break;
      case 7:
        m = Sanjagh.MARKET_CHARKHONEH;
        break;
      case 100:
      default:
        m = Sanjagh.MARKET_OTHER;
        break;
    }
    Sanjagh.setReleasedMarket(registrar.activity().getApplication(), m);
  }

  private void setPrimaryColor(String color){
    Sanjagh.setPrimaryColor(registrar.activity().getApplicationContext(), Color.parseColor(color));
  }

  private void setUserIdentifier(String identifier){
    Sanjagh.setUserIdentifier(registrar.activity().getApplicationContext(), identifier);
  }


  private void callLoadBannerAd(
          int id, Activity activity, MethodChannel channel, MethodCall call, Result result) {
    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error("no_unit_id", "a null or empty adUnitId was provided for ad id=" + id, null);
      return;
    }

    MobileAd.Banner banner = MobileAd.createBanner(id/*, adSize*/, activity, channel);
    banner.setExpandableOptions((boolean) call.argument("expandable"),(boolean) call.argument("transformable"),(int) call.argument("entranceType"));
    if (banner.status != MobileAd.Status.CREATED) {
      if (banner.status == MobileAd.Status.FAILED) {
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + id, null);
        return;
      }
//            else result.success(Boolean.TRUE); // The ad was already loaded.
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    banner.status = MobileAd.Status.CREATED;
    banner.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }
  private void callLoadNativeExpressAd(
          int id, Activity activity, MethodChannel channel, MethodCall call, Result result) {
    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error("no_unit_id", "a null or empty adUnitId was provided for ad id=" + id, null);
      return;
    }

    MobileAd.NativeExpress nativeExpress = MobileAd.createNativeExpress(id/*, adSize*/, activity, channel);
    if (nativeExpress.status != MobileAd.Status.CREATED) {
      if (nativeExpress.status == MobileAd.Status.FAILED) {
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + id, null);
        return;
      }
//            else result.success(Boolean.TRUE); // The ad was already loaded.
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    nativeExpress.status = MobileAd.Status.CREATED;
    nativeExpress.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }
  private void callLoadInterstitialAd(MobileAd ad, MethodCall call, Result result) {
    if (ad.status != MobileAd.Status.CREATED) {
      if (ad.status == MobileAd.Status.FAILED)
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + ad.id, null);
      else result.success(Boolean.TRUE); // The ad was already loaded.
      return;
    }

    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error(
              "no_adunit_id", "a null or empty adUnitId was provided for ad id=" + ad.id, null);
      return;
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    ad.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }

  private void callShowAd(int id, MethodCall call, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("ad_not_loaded", "show failed, the specified ad was not loaded id=" + id, null);
      return;
    }
    if (call.argument("anchorOffset") != null) {
      ad.anchorOffset = Double.parseDouble((String) call.argument("anchorOffset"));
    }
    if (call.argument("anchorType") != null) {
      ad.anchorType = call.argument("anchorType").equals("bottom") ? Gravity.BOTTOM : Gravity.TOP;
    }

    ad.show();
    result.success(Boolean.TRUE);
  }

}

==> sanjagh_flutter-0.0.4.tar.gz: android/src/main/java/com/sanjagh/sanjagh_flutter/SanjaghFlutterPlugin.java <==
package com.sanjagh.sanjagh_flutter;

import android.app.Activity;
import android.graphics.Color;
import android.view.Gravity;

import com.sanjagh.sdk.Sanjagh;

import java.util.Map;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterSdkPlugin
 */
public class SanjaghFlutterPlugin implements MethodCallHandler {

  private final Registrar registrar;
  private final MethodChannel channel;



  private SanjaghFlutterPlugin(Registrar registrar, MethodChannel channel) {
    this.registrar = registrar;
    this.channel = channel;
  }

  /**
   * Plugin registration.
   */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_sdk");
    registrar
            .platformViewRegistry()
            .registerViewFactory(
                    "com.sanjagh.sdk/banner", new BannerViewFactory(registrar.messenger(),registrar.activity()));
    channel.setMethodCallHandler(new SanjaghFlutterPlugin(registrar, channel));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
    int id = 0;
    if (call.hasArgument("id")){
      id = call.argument("id");
    }
    switch (call.method) {
      case "getPlatformVersion":
        result.success("Android " + android.os.Build.VERSION.RELEASE);
        break;
      case "initialize":
        initSDK((String) call.argument("appId"));
        break;
      case "setMarket":
        setMarket((int) call.argument("market"));
        break;
      case "setPrimaryColor":
        setPrimaryColor((String) call.argument("color"));
        break;
      case "setUserIdentifier":
        setUserIdentifier((String) call.argument("userIdentifier"));
        break;
      case "showBanner":
        callLoadBannerAd(id, registrar.activity(), channel, call, result);
        break;
      case "showNativeExpress":
        callLoadNativeExpressAd(id, registrar.activity(), channel, call ,result);
        break;
      case "loadInterstitialAd":
        callLoadInterstitialAd(MobileAd.createInterstitial(id, registrar.activity(), channel), call, result);
        break;
      case "showAd":
        callShowAd(id, call, result);
        break;
      default:
        result.notImplemented();
        break;
    }
  }

  private void initSDK(String appId) {
    Sanjagh.initialize(registrar.activity().getApplication(), appId);
  }

  private void setMarket(int market) {
    @Sanjagh.Markets int m;
    switch (market){
      case 1:
        m = Sanjagh.MARKET_GOOGLE_PLAY;
        break;
      case 2:
        m = Sanjagh.MARKET_CAFE_BAZAAR;
        break;
      case 3:
        m = Sanjagh.MARKET_MYKET;
        break;
      case 4:
        m = Sanjagh.MARKET_IRAN_APPS;
        break;
      case 5:
        m = Sanjagh.MARKET_AVVAL_MARKET;
        break;
      case 6:
        m = Sanjagh.MARKET_CANDO;
        break;
      case 7:
        m = Sanjagh.MARKET_CHARKHONEH;
        break;
      case 100:
      default:
        m = Sanjagh.MARKET_OTHER;
        break;
    }
    Sanjagh.setReleasedMarket(registrar.activity().getApplication(), m);
  }

  private void setPrimaryColor(String color){
    Sanjagh.setPrimaryColor(registrar.activity().getApplicationContext(), Color.parseColor(color));
  }

  private void setUserIdentifier(String identifier){
    Sanjagh.setUserIdentifier(registrar.activity().getApplicationContext(), identifier);
  }


  private void callLoadBannerAd(
          int id, Activity activity, MethodChannel channel, MethodCall call, Result result) {
    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error("no_unit_id", "a null or empty adUnitId was provided for ad id=" + id, null);
      return;
    }

    MobileAd.Banner banner = MobileAd.createBanner(id/*, adSize*/, activity, channel);
    banner.setExpandableOptions((boolean) call.argument("expandable"),(boolean) call.argument("transformable"),(int) call.argument("entranceType"));
    if (banner.status != MobileAd.Status.CREATED) {
      if (banner.status == MobileAd.Status.FAILED) {
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + id, null);
        return;
      }
//            else result.success(Boolean.TRUE); // The ad was already loaded.
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    banner.status = MobileAd.Status.CREATED;
    banner.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }
  private void callLoadNativeExpressAd(
          int id, Activity activity, MethodChannel channel, MethodCall call, Result result) {
    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error("no_unit_id", "a null or empty adUnitId was provided for ad id=" + id, null);
      return;
    }

    MobileAd.NativeExpress nativeExpress = MobileAd.createNativeExpress(id/*, adSize*/, activity, channel);
    if (nativeExpress.status != MobileAd.Status.CREATED) {
      if (nativeExpress.status == MobileAd.Status.FAILED) {
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + id, null);
        return;
      }
//            else result.success(Boolean.TRUE); // The ad was already loaded.
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    nativeExpress.status = MobileAd.Status.CREATED;
    nativeExpress.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }
  private void callLoadInterstitialAd(MobileAd ad, MethodCall call, Result result) {
    if (ad.status != MobileAd.Status.CREATED) {
      if (ad.status == MobileAd.Status.FAILED)
        result.error("load_failed_ad", "cannot reload a failed ad, id=" + ad.id, null);
      else result.success(Boolean.TRUE); // The ad was already loaded.
      return;
    }

    String adUnitId = call.argument("adUnitId");
    if (adUnitId == null || adUnitId.isEmpty()) {
      result.error(
              "no_adunit_id", "a null or empty adUnitId was provided for ad id=" + ad.id, null);
      return;
    }
    Map<String, Object> targetingInfo = call.argument("targetingInfo");
    ad.load(adUnitId, targetingInfo);
    result.success(Boolean.TRUE);
  }

  private void callShowAd(int id, MethodCall call, Result result) {
    MobileAd ad = MobileAd.getAdForId(id);
    if (ad == null) {
      result.error("ad_not_loaded", "show failed, the specified ad was not loaded id=" + id, null);
      return;
    }
    if (call.argument("anchorOffset") != null) {
      ad.anchorOffset = Double.parseDouble((String) call.argument("anchorOffset"));
    }
    if (call.argument("anchorType") != null) {
      ad.anchorType = call.argument("anchorType").equals("bottom") ? Gravity.BOTTOM : Gravity.TOP;
    }

    ad.show();
    result.success(Boolean.TRUE);
  }

}
